@@ -1,6 +1,6 @@
 import calendar
 import json
-from logging import getLogger
+from logging import getLogger, NullHandler
 from collections import defaultdict
 from datetime import datetime, timedelta
 from hashlib import sha256
@@ -47,6 +47,7 @@ JOB_DESTINATION_FORMAT_NEWLINE_DELIMITED_JSON = \
 JOB_DESTINATION_FORMAT_CSV = JOB_FORMAT_CSV
 
 logger = getLogger(__name__)
+logger.addHandler(NullHandler())
 
 
 def get_client(project_id=None, credentials=None,
@@ -679,7 +680,7 @@ class BigQueryClient(object):
             else:
                 return {}
 
-    def create_view(self, dataset, view, query):
+    def create_view(self, dataset, view, query, use_legacy_sql=None):
         """Create a new view in the dataset.
 
         Parameters
@@ -690,6 +691,9 @@ class BigQueryClient(object):
             The name of the view to create
         query : dict
             A query that BigQuery executes when the view is referenced.
+        use_legacy_sql : bool, optional
+            If False, the query will use BigQuery's standard SQL
+            (https://cloud.google.com/bigquery/sql-reference/)
 
         Returns
         -------
@@ -709,6 +713,9 @@ class BigQueryClient(object):
             }
         }
 
+        if use_legacy_sql is not None:
+            body['view']['useLegacySql'] = use_legacy_sql
+
         try:
             view = self.bigquery.tables().insert(
                 projectId=self.project_id,
